"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isReferenced = exports.bulkRemoveReferences = exports.bulkReplaceReferences = exports.bulkInsertReferences = exports.queryReferenced = exports.bulkRemove = exports.bulkUpdate = exports.bulkSave = exports.bulkInsert = exports.distinct = exports.count = exports.aggregate = exports.query = exports.truncate = exports.remove = exports.get = exports.save = exports.update = exports.insert = exports.Order = exports.SortOrder = exports.Segment = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixDataV1DataService = __importStar(require("./data-v1-data-service-data.http.js"));
var Segment;
(function (Segment) {
    /** Access database used in the Live site. */
    Segment["LIVE"] = "LIVE";
    /** Access staging (sandbox) database used in the editor. */
    Segment["SANDBOX"] = "SANDBOX";
    /** Access deleted database used in the Live site. */
    Segment["TRASH_LIVE"] = "TRASH_LIVE";
})(Segment || (exports.Segment = Segment = {}));
var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (exports.SortOrder = SortOrder = {}));
var Order;
(function (Order) {
    Order["ASC"] = "ASC";
    Order["DESC"] = "DESC";
})(Order || (exports.Order = Order = {}));
/**
 * Adds an item to a collection.
 *
 * When an item is inserted into a collection, the following properties and values are added to it:
 * * `_id`: A unique identifier for an item in a collection. You can optionally provide your own ID when inserting the item. If you specify an ID that already exists in the collection, the insertion will fail.
 * * `_createdDate`: The date the item was added to the collection.
 * * `_updatedDate`: The date the item was last modified. When the item is first inserted, `_createdDate` and `_updatedDate` have the same value.
 * @internal
 * @documentationMaturity preview
 * @permissionId WIX_DATA.INSERT
 * @permissionScope Write Data Items
 * @permissionScopeId SCOPE.DC-DATA.WRITE
 * @applicableIdentity APP
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.Insert
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function insert(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        item: options?.item,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.insert(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                item: '$[0].item',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.insert = insert;
/**
 * Updates an item in a collection.
 *
 * An item ID must be submitted as part of the request, either as a path parameter or within the `item` body parameter. If an item is found in the specified collection with
 * the same ID, that item is updated. If the collection doesn't contain an item with that ID, the request fails.
 *
 * When an item is updated, its `_updatedDate` property is changed to the current date.
 *
 * **Note:**
 * After an item is updated, it only contains the properties included in the Update Data Item request. If the existing item has properties with values and those properties
 * aren't included in the updated item, their values are lost.
 * @internal
 * @documentationMaturity preview
 * @requiredField options.item
 * @permissionId WIX_DATA.UPDATE
 * @permissionScope Write Data Items
 * @permissionScopeId SCOPE.DC-DATA.WRITE
 * @applicableIdentity APP
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.Update
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function update(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        item: options?.item,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.update(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                item: '$[0].item',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.update = update;
/**
 * Inserts or updates an item in a collection.
 *
 * The Save Data Item endpoint inserts or updates the specified item, depending on whether it already exists in the collection.
 *
 * * If you don't provide an ID, a new item is created.
 *
 * * If you provide an ID that doesn't exist in the collection, a new item is created with that ID.
 *
 * * If an item with the ID you provide already exists in the collection, that item is updated. When an item is updated, its `_updatedDate` property is changed to the current date.
 *
 * ***Note:*** When you provide an item with an ID that already exists in the collection, the item you provide completely replaces the existing item with that ID.
 * This means that all of the item's previous properties and values are lost.
 * @internal
 * @documentationMaturity preview
 * @permissionId WIX_DATA.UPDATE
 * @permissionScope Write Data Items
 * @permissionScopeId SCOPE.DC-DATA.WRITE
 * @applicableIdentity APP
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.Save
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function save(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        item: options?.item,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.save(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                item: '$[0].item',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.save = save;
/**
 * Retrieves an item from a collection.
 * @param itemId - ID of the item to retrieve.
 * @internal
 * @documentationMaturity preview
 * @requiredField itemId
 * @permissionId WIX_DATA.FIND
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.Get
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function get(itemId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        itemId: itemId,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.get(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                itemId: '$[0]',
                dataCollectionId: '$[1].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['itemId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.get = get;
/**
 * Removes an item from a collection.
 *
 * If any items in other collections reference the removed item in a reference or multi-reference field, the field is cleared.
 *
 * **Note:**
 * Once an item has been removed from a collection, it can't be restored.
 * @param itemId - ID of the item to remove.
 * @internal
 * @documentationMaturity preview
 * @requiredField itemId
 * @permissionId WIX_DATA.REMOVE
 * @permissionScope Write Data Items
 * @permissionScopeId SCOPE.DC-DATA.WRITE
 * @applicableIdentity APP
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.Remove
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function remove(itemId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        itemId: itemId,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.remove(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                itemId: '$[0]',
                dataCollectionId: '$[1].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['itemId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.remove = remove;
/**
 * Removes all items from a collection. Site owner (`ADMIN`) permissions are required in order to invoke this operation.
 *
 * If any items in other collections reference the removed items in reference or multi-reference fields, those fields are cleared.
 *
 * **Note:**
 * Once items have been removed from a collection, they can't be restored.
 * @internal
 * @documentationMaturity preview
 * @permissionId WIX_DATA.TRUNCATE
 * @permissionScope Write Data Items
 * @permissionScopeId SCOPE.DC-DATA.WRITE
 * @applicableIdentity APP
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.Truncate
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function truncate(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.truncate(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { dataCollectionId: '$[0].dataCollectionId' },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.truncate = truncate;
/**
 * Retrieves a list of items, on the basis of the filtering, sorting, and paging preferences you provide.
 *
 * For more details on using queries, see [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language).
 * @public
 * @documentationMaturity preview
 * @permissionId WIX_DATA.FIND
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.Query
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function query(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        dataQuery: options?.dataQuery,
        omitTotalCount: options?.omitTotalCount,
        includeReferencedItems: options?.includeReferencedItems,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.query(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                dataQuery: '$[0].dataQuery',
                omitTotalCount: '$[0].omitTotalCount',
                includeReferencedItems: '$[0].includeReferencedItems',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.query = query;
/** @internal
 * @documentationMaturity preview
 * @permissionId WIX_DATA.AGGREGATE
 * @permissionScope Read Data Items
 * @permissionScopeId SCOPE.DC-DATA.READ
 * @permissionScope Manage Data Items
 * @permissionScopeId SCOPE.DC-DATA.MANAGE-DATA
 * @applicableIdentity APP
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.Aggregate
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function aggregate(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        paging: options?.paging,
        initialFilter: options?.initialFilter,
        aggregation: options?.aggregation,
        finalFilter: options?.finalFilter,
        sort: options?.sort,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.aggregate(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                paging: '$[0].paging',
                initialFilter: '$[0].initialFilter',
                aggregation: '$[0].aggregation',
                finalFilter: '$[0].finalFilter',
                sort: '$[0].sort',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.aggregate = aggregate;
/**
 * Returns the number of items in a collection that match a query.
 * @internal
 * @documentationMaturity preview
 * @permissionId WIX_DATA.FIND
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.Count
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function count(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        filter: options?.filter,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.count(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                filter: '$[0].filter',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.count = count;
/**
 * Retrieves a list of distinct values for a given property in all items that match a query, without duplicates.
 *
 * As with the [Query Data Items]() endpoint, this endpoint retrieves items based on the filtering, sorting, and paging preferences you provide.
 * However, the Query Distinct Values endpoint doesn't return all of the full items that match the query.
 * Rather, it returns all unique values of the property you specify in `propertyName` for items that match the query.
 * If more than one item has the same value for that property, that value appears only once.
 *
 * For more details on using queries, see [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language).
 * @internal
 * @documentationMaturity preview
 * @requiredField options.propertyName
 * @permissionId WIX_DATA.FIND
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.Distinct
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function distinct(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        dataQuery: options?.dataQuery,
        propertyName: options?.propertyName,
        dataCollectionId: options?.dataCollectionId,
        omitTotalCount: options?.omitTotalCount,
    });
    const reqOpts = ambassadorWixDataV1DataService.distinct(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                dataQuery: '$[0].dataQuery',
                propertyName: '$[0].propertyName',
                dataCollectionId: '$[0].dataCollectionId',
                omitTotalCount: '$[0].omitTotalCount',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.distinct = distinct;
/**
 * Adds multiple items to a collection.
 *
 * When each item is inserted into a collection, the following properties and values are added to it:
 * * `_id`: A unique identifier for an item in a collection. You can optionally provide your own ID when inserting the item. If you specify an ID that already exists in the collection, the insertion will fail.
 * * `_createdDate`: The date the item was added to the collection.
 * * `_updatedDate`: The date the item was last modified. When the item is first inserted, `_createdDate` and `_updatedDate` have the same value.
 *
 * The endpoint returns a list of the IDs of items successfully inserted in `insertedItemIds`.
 * When any items can't be inserted, error details are provided for each failed item in `errors`.
 * @internal
 * @documentationMaturity preview
 * @requiredField options.items
 * @permissionId WIX_DATA.INSERT
 * @permissionScope Write Data Items
 * @permissionScopeId SCOPE.DC-DATA.WRITE
 * @applicableIdentity APP
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.BulkInsert
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function bulkInsert(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        items: options?.items,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.bulkInsert(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                items: '$[0].items',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.bulkInsert = bulkInsert;
/**
 * Inserts or updates multiple items in a collection.
 *
 * The Bulk Save Data Items endpoint inserts or updates each item, depending on whether it already exists in the collection. For each item:
 *
 * * If you don't provide an ID, a new item is created.
 *
 * * If you provide an ID that doesn't exist in the collection, a new item is created with that ID.
 *
 * * If an item with the ID you provide already exists in the collection, that item is updated. When an item is updated, its `_updatedDate` property is changed to the current date.
 *
 * The endpoint returns a list of the IDs of items successfully inserted in `insertedItemIds` and a list of the IDs of items successfully updated in `updatedItemIds`.
 * When any items can't be inserted or updated, error details are provided for each failed item in `errors`.
 *
 * ***Note:*** When you provide an item with an ID that already exists in the collection, the item you provide completely replaces the existing item with that ID.
 * This means that all of the item's previous properties and values are lost.
 * @internal
 * @documentationMaturity preview
 * @requiredField options.items
 * @permissionId WIX_DATA.UPDATE
 * @permissionScope Write Data Items
 * @permissionScopeId SCOPE.DC-DATA.WRITE
 * @applicableIdentity APP
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.BulkSave
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function bulkSave(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        items: options?.items,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.bulkSave(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                items: '$[0].items',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.bulkSave = bulkSave;
/**
 * Updates multiple items in a collection.
 *
 * Each item in the request must include an ID. If an item is found in the specified collection with
 * the same ID, that item is updated. If the collection doesn't contain an item with that ID, the update fails.
 *
 * When an item is updated, its `_updatedDate` property is changed to the current date.
 *
 * The endpoint returns a list of the IDs of items successfully updated in `updatedItemIds`.
 * When any items can't be inserted, error details are provided for each failed item in `errors`.
 *
 * **Note:**
 * After each item is updated, it only contains the properties included in the Update Data Item request. If the existing item has properties with values and those properties
 * aren't included in the updated item, their values are lost.
 * @internal
 * @documentationMaturity preview
 * @requiredField options.items
 * @permissionId WIX_DATA.UPDATE
 * @permissionScope Write Data Items
 * @permissionScopeId SCOPE.DC-DATA.WRITE
 * @applicableIdentity APP
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.BulkUpdate
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function bulkUpdate(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        items: options?.items,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.bulkUpdate(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                items: '$[0].items',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.bulkUpdate = bulkUpdate;
/**
 * Removes multiple items from a collection.
 *
 * If any items in other collections reference the removed items in reference or multi-reference fields, the fields are cleared.
 *
 * The endpoint returns a list of the IDs of items successfully removed in `removedItemIds`.
 * When any items can't be removed, error details are provided for each failed item in `errors`.
 *
 * **Note:** Once an item has been removed from a collection, it can't be restored.
 * @internal
 * @documentationMaturity preview
 * @permissionId WIX_DATA.REMOVE
 * @permissionScope Write Data Items
 * @permissionScopeId SCOPE.DC-DATA.WRITE
 * @applicableIdentity APP
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.BulkRemove
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function bulkRemove(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        entries: options?.entries,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.bulkRemove(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                entries: '$[0].entries',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.bulkRemove = bulkRemove;
/**
 * Gets the full items referenced in the specified property of an item.
 *
 * For example, suppose you have a **Movies** collection with an **Actors** field that contains references to items in a **People** collection.
 * Querying the **Movies** collection using the Query Referenced Data Items endpoint returns the relevant **People** items referenced in the **Actors** field of the specified **Movie** item.
 * This gives you information from the **People** collection about each of the actors in the specified movie.
 * @internal
 * @documentationMaturity preview
 * @requiredField options.propertyName
 * @requiredField options.referringItemId
 * @permissionId WIX_DATA.FIND
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.QueryReferenced
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function queryReferenced(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        referringItemId: options?.referringItemId,
        propertyName: options?.propertyName,
        paging: options?.paging,
        dataCollectionId: options?.dataCollectionId,
        omitTotalCount: options?.omitTotalCount,
    });
    const reqOpts = ambassadorWixDataV1DataService.queryReferenced(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                referringItemId: '$[0].referringItemId',
                propertyName: '$[0].propertyName',
                paging: '$[0].paging',
                dataCollectionId: '$[0].dataCollectionId',
                omitTotalCount: '$[0].omitTotalCount',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.queryReferenced = queryReferenced;
/**
 * Inserts one or more references in the specified properties of items in a collection.
 *
 * The Bulk Insert References endpoint adds one or more references to a collection.
 * Each new reference in the `references` field specifies a referring item's ID, the property in which to insert the reference, and the ID of the referenced item.
 * @internal
 * @documentationMaturity preview
 * @requiredField options.references
 * @requiredField options.references.propertyName
 * @requiredField options.references.referencedItemId
 * @requiredField options.references.referringItemId
 * @permissionId WIX_DATA.INSERT
 * @permissionScope Write Data Items
 * @permissionScopeId SCOPE.DC-DATA.WRITE
 * @applicableIdentity APP
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.BulkInsertReferences
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function bulkInsertReferences(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        references: options?.references,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.bulkInsertReferences(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                references: '$[0].references',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.bulkInsertReferences = bulkInsertReferences;
/**
 * Replaces references in a specified property of a specified data item.
 *
 * The Bulk Replace References endpoint replaces the existing reference or references contained in the property specified in `propertyName` within the data item specified in `referringItemId`.
 * The endpoint removes existing references and in their place it adds references to the items specified in `newReferencedItemIds`.
 * @internal
 * @documentationMaturity preview
 * @requiredField options.propertyName
 * @requiredField options.referringItemId
 * @permissionId WIX_DATA.UPDATE
 * @permissionScope Write Data Items
 * @permissionScopeId SCOPE.DC-DATA.WRITE
 * @applicableIdentity APP
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.BulkReplaceReferences
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function bulkReplaceReferences(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        propertyName: options?.propertyName,
        referringItemId: options?.referringItemId,
        newReferencedItemIds: options?.newReferencedItemIds,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.bulkReplaceReferences(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                propertyName: '$[0].propertyName',
                referringItemId: '$[0].referringItemId',
                newReferencedItemIds: '$[0].newReferencedItemIds',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.bulkReplaceReferences = bulkReplaceReferences;
/**
 * Removes one or more references.
 * @internal
 * @documentationMaturity preview
 * @requiredField options.references
 * @requiredField options.references.propertyName
 * @permissionId WIX_DATA.REMOVE
 * @permissionScope Write Data Items
 * @permissionScopeId SCOPE.DC-DATA.WRITE
 * @applicableIdentity APP
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.BulkRemoveReferences
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function bulkRemoveReferences(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        references: options?.references,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.bulkRemoveReferences(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                references: '$[0].references',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.bulkRemoveReferences = bulkRemoveReferences;
/**
 * Checks if a specific property of a referring item contains a reference to another specific item.
 * @internal
 * @documentationMaturity preview
 * @requiredField options.propertyName
 * @requiredField options.referencedItemId
 * @requiredField options.referringItemId
 * @permissionId WIX_DATA.FIND
 * @fqn com.wixpress.cloud.data.api.dataservice.WixDataService.IsReferenced
 * @deprecated
 * @targetRemovalDate 2025-06-01
 */
async function isReferenced(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        propertyName: options?.propertyName,
        referringItemId: options?.referringItemId,
        referencedItemId: options?.referencedItemId,
        dataCollectionId: options?.dataCollectionId,
    });
    const reqOpts = ambassadorWixDataV1DataService.isReferenced(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                propertyName: '$[0].propertyName',
                referringItemId: '$[0].referringItemId',
                referencedItemId: '$[0].referencedItemId',
                dataCollectionId: '$[0].dataCollectionId',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.isReferenced = isReferenced;
//# sourceMappingURL=data-v1-data-service-data.universal.js.map