import { HttpClient } from '@wix/sdk-types';
import { AggregateOptions, AggregationResponse, BulkInsertOptions, BulkInsertReferencesOptions, BulkInsertResponse, BulkInsertResponseNonNullableFields, BulkRemoveOptions, BulkRemoveReferencesOptions, BulkRemoveResponse, BulkRemoveResponseNonNullableFields, BulkReplaceReferencesOptions, BulkSaveOptions, BulkSaveResponse, BulkSaveResponseNonNullableFields, BulkUpdateOptions, BulkUpdateResponse, BulkUpdateResponseNonNullableFields, CountOptions, CountResponse, CountResponseNonNullableFields, DistinctOptions, DistinctResponse, GetOptions, GetResponse, InsertOptions, InsertResponse, IsReferencedOptions, IsReferencedResponse, IsReferencedResponseNonNullableFields, QueryOptions, QueryReferencedOptions, QueryReferencedResponse, QueryReferencedResponseNonNullableFields, QueryResponse, QueryResponseNonNullableFields, RemoveOptions, RemoveResponse, SaveOptions, SaveResponse, TruncateOptions, UpdateOptions, UpdateResponse } from './data-v1-data-service-data.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
/** @internal */
export declare function insert(httpClient: HttpClient): InsertSignature;
interface InsertSignature {
    /**
     * Adds an item to a collection.
     *
     * When an item is inserted into a collection, the following properties and values are added to it:
     * * `_id`: A unique identifier for an item in a collection. You can optionally provide your own ID when inserting the item. If you specify an ID that already exists in the collection, the insertion will fail.
     * * `_createdDate`: The date the item was added to the collection.
     * * `_updatedDate`: The date the item was last modified. When the item is first inserted, `_createdDate` and `_updatedDate` have the same value.
     * @deprecated
     */
    (options?: InsertOptions | undefined): Promise<InsertResponse>;
}
/** @internal */
export declare function update(httpClient: HttpClient): UpdateSignature;
interface UpdateSignature {
    /**
     * Updates an item in a collection.
     *
     * An item ID must be submitted as part of the request, either as a path parameter or within the `item` body parameter. If an item is found in the specified collection with
     * the same ID, that item is updated. If the collection doesn't contain an item with that ID, the request fails.
     *
     * When an item is updated, its `_updatedDate` property is changed to the current date.
     *
     * **Note:**
     * After an item is updated, it only contains the properties included in the Update Data Item request. If the existing item has properties with values and those properties
     * aren't included in the updated item, their values are lost.
     * @deprecated
     */
    (options?: UpdateOptions | undefined): Promise<UpdateResponse>;
}
/** @internal */
export declare function save(httpClient: HttpClient): SaveSignature;
interface SaveSignature {
    /**
     * Inserts or updates an item in a collection.
     *
     * The Save Data Item endpoint inserts or updates the specified item, depending on whether it already exists in the collection.
     *
     * * If you don't provide an ID, a new item is created.
     *
     * * If you provide an ID that doesn't exist in the collection, a new item is created with that ID.
     *
     * * If an item with the ID you provide already exists in the collection, that item is updated. When an item is updated, its `_updatedDate` property is changed to the current date.
     *
     * ***Note:*** When you provide an item with an ID that already exists in the collection, the item you provide completely replaces the existing item with that ID.
     * This means that all of the item's previous properties and values are lost.
     * @deprecated
     */
    (options?: SaveOptions | undefined): Promise<SaveResponse>;
}
/** @internal */
export declare function get(httpClient: HttpClient): GetSignature;
interface GetSignature {
    /**
     * Retrieves an item from a collection.
     * @param - ID of the item to retrieve.
     * @deprecated
     */
    (itemId: string, options?: GetOptions | undefined): Promise<GetResponse>;
}
/** @internal */
export declare function remove(httpClient: HttpClient): RemoveSignature;
interface RemoveSignature {
    /**
     * Removes an item from a collection.
     *
     * If any items in other collections reference the removed item in a reference or multi-reference field, the field is cleared.
     *
     * **Note:**
     * Once an item has been removed from a collection, it can't be restored.
     * @param - ID of the item to remove.
     * @deprecated
     */
    (itemId: string, options?: RemoveOptions | undefined): Promise<RemoveResponse>;
}
/** @internal */
export declare function truncate(httpClient: HttpClient): TruncateSignature;
interface TruncateSignature {
    /**
     * Removes all items from a collection. Site owner (`ADMIN`) permissions are required in order to invoke this operation.
     *
     * If any items in other collections reference the removed items in reference or multi-reference fields, those fields are cleared.
     *
     * **Note:**
     * Once items have been removed from a collection, they can't be restored.
     * @deprecated
     */
    (options?: TruncateOptions | undefined): Promise<void>;
}
export declare function query(httpClient: HttpClient): QuerySignature;
interface QuerySignature {
    /**
     * Retrieves a list of items, on the basis of the filtering, sorting, and paging preferences you provide.
     *
     * For more details on using queries, see [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language).
     * @deprecated
     */
    (options?: QueryOptions | undefined): Promise<QueryResponse & QueryResponseNonNullableFields>;
}
/** @internal */
export declare function aggregate(httpClient: HttpClient): AggregateSignature;
interface AggregateSignature {
    /** @deprecated */
    (options?: AggregateOptions | undefined): Promise<AggregationResponse>;
}
/** @internal */
export declare function count(httpClient: HttpClient): CountSignature;
interface CountSignature {
    /**
     * Returns the number of items in a collection that match a query.
     * @deprecated
     */
    (options?: CountOptions | undefined): Promise<CountResponse & CountResponseNonNullableFields>;
}
/** @internal */
export declare function distinct(httpClient: HttpClient): DistinctSignature;
interface DistinctSignature {
    /**
     * Retrieves a list of distinct values for a given property in all items that match a query, without duplicates.
     *
     * As with the [Query Data Items]() endpoint, this endpoint retrieves items based on the filtering, sorting, and paging preferences you provide.
     * However, the Query Distinct Values endpoint doesn't return all of the full items that match the query.
     * Rather, it returns all unique values of the property you specify in `propertyName` for items that match the query.
     * If more than one item has the same value for that property, that value appears only once.
     *
     * For more details on using queries, see [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language).
     * @deprecated
     */
    (options?: DistinctOptions | undefined): Promise<DistinctResponse>;
}
/** @internal */
export declare function bulkInsert(httpClient: HttpClient): BulkInsertSignature;
interface BulkInsertSignature {
    /**
     * Adds multiple items to a collection.
     *
     * When each item is inserted into a collection, the following properties and values are added to it:
     * * `_id`: A unique identifier for an item in a collection. You can optionally provide your own ID when inserting the item. If you specify an ID that already exists in the collection, the insertion will fail.
     * * `_createdDate`: The date the item was added to the collection.
     * * `_updatedDate`: The date the item was last modified. When the item is first inserted, `_createdDate` and `_updatedDate` have the same value.
     *
     * The endpoint returns a list of the IDs of items successfully inserted in `insertedItemIds`.
     * When any items can't be inserted, error details are provided for each failed item in `errors`.
     * @deprecated
     */
    (options?: BulkInsertOptions | undefined): Promise<BulkInsertResponse & BulkInsertResponseNonNullableFields>;
}
/** @internal */
export declare function bulkSave(httpClient: HttpClient): BulkSaveSignature;
interface BulkSaveSignature {
    /**
     * Inserts or updates multiple items in a collection.
     *
     * The Bulk Save Data Items endpoint inserts or updates each item, depending on whether it already exists in the collection. For each item:
     *
     * * If you don't provide an ID, a new item is created.
     *
     * * If you provide an ID that doesn't exist in the collection, a new item is created with that ID.
     *
     * * If an item with the ID you provide already exists in the collection, that item is updated. When an item is updated, its `_updatedDate` property is changed to the current date.
     *
     * The endpoint returns a list of the IDs of items successfully inserted in `insertedItemIds` and a list of the IDs of items successfully updated in `updatedItemIds`.
     * When any items can't be inserted or updated, error details are provided for each failed item in `errors`.
     *
     * ***Note:*** When you provide an item with an ID that already exists in the collection, the item you provide completely replaces the existing item with that ID.
     * This means that all of the item's previous properties and values are lost.
     * @deprecated
     */
    (options?: BulkSaveOptions | undefined): Promise<BulkSaveResponse & BulkSaveResponseNonNullableFields>;
}
/** @internal */
export declare function bulkUpdate(httpClient: HttpClient): BulkUpdateSignature;
interface BulkUpdateSignature {
    /**
     * Updates multiple items in a collection.
     *
     * Each item in the request must include an ID. If an item is found in the specified collection with
     * the same ID, that item is updated. If the collection doesn't contain an item with that ID, the update fails.
     *
     * When an item is updated, its `_updatedDate` property is changed to the current date.
     *
     * The endpoint returns a list of the IDs of items successfully updated in `updatedItemIds`.
     * When any items can't be inserted, error details are provided for each failed item in `errors`.
     *
     * **Note:**
     * After each item is updated, it only contains the properties included in the Update Data Item request. If the existing item has properties with values and those properties
     * aren't included in the updated item, their values are lost.
     * @deprecated
     */
    (options?: BulkUpdateOptions | undefined): Promise<BulkUpdateResponse & BulkUpdateResponseNonNullableFields>;
}
/** @internal */
export declare function bulkRemove(httpClient: HttpClient): BulkRemoveSignature;
interface BulkRemoveSignature {
    /**
     * Removes multiple items from a collection.
     *
     * If any items in other collections reference the removed items in reference or multi-reference fields, the fields are cleared.
     *
     * The endpoint returns a list of the IDs of items successfully removed in `removedItemIds`.
     * When any items can't be removed, error details are provided for each failed item in `errors`.
     *
     * **Note:** Once an item has been removed from a collection, it can't be restored.
     * @deprecated
     */
    (options?: BulkRemoveOptions | undefined): Promise<BulkRemoveResponse & BulkRemoveResponseNonNullableFields>;
}
/** @internal */
export declare function queryReferenced(httpClient: HttpClient): QueryReferencedSignature;
interface QueryReferencedSignature {
    /**
     * Gets the full items referenced in the specified property of an item.
     *
     * For example, suppose you have a **Movies** collection with an **Actors** field that contains references to items in a **People** collection.
     * Querying the **Movies** collection using the Query Referenced Data Items endpoint returns the relevant **People** items referenced in the **Actors** field of the specified **Movie** item.
     * This gives you information from the **People** collection about each of the actors in the specified movie.
     * @deprecated
     */
    (options?: QueryReferencedOptions | undefined): Promise<QueryReferencedResponse & QueryReferencedResponseNonNullableFields>;
}
/** @internal */
export declare function bulkInsertReferences(httpClient: HttpClient): BulkInsertReferencesSignature;
interface BulkInsertReferencesSignature {
    /**
     * Inserts one or more references in the specified properties of items in a collection.
     *
     * The Bulk Insert References endpoint adds one or more references to a collection.
     * Each new reference in the `references` field specifies a referring item's ID, the property in which to insert the reference, and the ID of the referenced item.
     * @deprecated
     */
    (options?: BulkInsertReferencesOptions | undefined): Promise<void>;
}
/** @internal */
export declare function bulkReplaceReferences(httpClient: HttpClient): BulkReplaceReferencesSignature;
interface BulkReplaceReferencesSignature {
    /**
     * Replaces references in a specified property of a specified data item.
     *
     * The Bulk Replace References endpoint replaces the existing reference or references contained in the property specified in `propertyName` within the data item specified in `referringItemId`.
     * The endpoint removes existing references and in their place it adds references to the items specified in `newReferencedItemIds`.
     * @deprecated
     */
    (options?: BulkReplaceReferencesOptions | undefined): Promise<void>;
}
/** @internal */
export declare function bulkRemoveReferences(httpClient: HttpClient): BulkRemoveReferencesSignature;
interface BulkRemoveReferencesSignature {
    /**
     * Removes one or more references.
     * @deprecated
     */
    (options?: BulkRemoveReferencesOptions | undefined): Promise<void>;
}
/** @internal */
export declare function isReferenced(httpClient: HttpClient): IsReferencedSignature;
interface IsReferencedSignature {
    /**
     * Checks if a specific property of a referring item contains a reference to another specific item.
     * @deprecated
     */
    (options?: IsReferencedOptions | undefined): Promise<IsReferencedResponse & IsReferencedResponseNonNullableFields>;
}
export { AggregateOptions, AggregationRequest, AggregationResponse, ApplicationError, BulkError, BulkInsertOptions, BulkInsertReferencesOptions, BulkInsertReferencesRequest, BulkInsertReferencesResponse, BulkInsertRequest, BulkInsertResponse, BulkInsertResponseNonNullableFields, BulkPatchRequest, BulkPatchResponse, BulkRemoveOptions, BulkRemoveReferencesOptions, BulkRemoveReferencesRequest, BulkRemoveReferencesResponse, BulkRemoveRequest, BulkRemoveRequestEntry, BulkRemoveResponse, BulkRemoveResponseNonNullableFields, BulkReplaceReferencesOptions, BulkReplaceReferencesRequest, BulkReplaceReferencesResponse, BulkSaveOptions, BulkSaveRequest, BulkSaveResponse, BulkSaveResponseNonNullableFields, BulkUpdateOptions, BulkUpdateRequest, BulkUpdateResponse, BulkUpdateResponseNonNullableFields, CountOptions, CountRequest, CountResponse, CountResponseNonNullableFields, CursorPaging, Cursors, Details, DistinctOptions, DistinctRequest, DistinctResponse, Entry, GetOptions, GetRequest, GetResponse, InsertOptions, InsertRequest, InsertResponse, IsReferencedOptions, IsReferencedRequest, IsReferencedResponse, IsReferencedResponseNonNullableFields, Item, Options, Order, Paging, PagingMetadataV2, PatchRequest, PatchResponse, PatchWhereRequest, PatchWhereResponse, Query, QueryOptions, QueryReferencedOptions, QueryReferencedRequest, QueryReferencedResponse, QueryReferencedResponseNonNullableFields, QueryRequest, QueryResponse, QueryResponseNonNullableFields, QueryV2, QueryV2PagingMethodOneOf, ReadOptions, Reference, ReferencedEntity, ReferencedEntityEntityOneOf, RemoveOptions, RemoveRequest, RemoveResponse, RestoreFromTrashBinRequest, RestoreFromTrashBinResponse, SaveOptions, SaveRequest, SaveResponse, Segment, SortOrder, Sorting, TruncateOptions, TruncateRequest, TruncateResponse, UpdateOptions, UpdateRequest, UpdateResponse, } from './data-v1-data-service-data.universal.js';
